@@ -8,7 +8,7 @@ no warnings 'recursion';
 
 package XML::Compile::Schema::BuiltInTypes;
 use vars '$VERSION';
-$VERSION = '1.55';
+$VERSION = '1.56';
 
 use base 'Exporter';
 
@@ -263,7 +263,7 @@ $builtin_types{unsignedByte} =
 
 
 $builtin_types{decimal} =
- { parse   => sub {$_[0] =~ s/\s+//g; Math::BigFloat->new($_[0]) }
+ { parse   => sub {$_[0] =~ s/\s+//g; Math::BigFloat->new($_[0]) },
  , check   => sub {$_[0] =~ m/^(\+|\-)?([0-9]+(\.[0-9]*)?|\.[0-9]+)$/}
  , example => '3.1415'
  , extends => 'anyAtomicType'
